@@ -1,7 +1,7 @@
 #' Download button
 #'
-#' Wrapper around \code{bsplus::\link[bsplus]{bs_button}} to provide a download button for HTML outputs in R Markdown.
-#' Internally, the function writes the file to `tempdir()`, encodes it, and produces the download button.
+#' Wrapper around \code{bsplus::bs_button()} to provide a download button for HTML outputs in R Markdown.
+#' Internally, the function writes the file to \code{tempdir()}, encodes it, and produces the download button. Currently, Internet Explorer does not support downloading embedded files.
 #'
 #' @param .data A data frame or (named) list to write to disk. See 'Examples' for more details.
 #' @param output_name Name of of the output file.
@@ -17,7 +17,7 @@
 #' @export
 #'
 #' @section Warning:
-#' This example will write the `mtcars` dataset to `tempdir()` and produce the download button for the file `mtcars dataset.csv` with the `fa fa-save` icon on the `Download data` label.
+#' This example will write the \code{mtcars} dataset to \code{tempdir()} and produce the download button for the file `mtcars dataset.csv` with the `fa fa-save` icon on the `Download data` label.
 #'
 #' @examples
 #' # Passing a data frame to the function
@@ -64,7 +64,7 @@ download_this <- function(
 ){
 
   ## check if .data argument only contains data frames (if list is passed) or a single data frame
-  if(class(.data) == "list") {
+  if("list" %in% class(.data)) {
     if(!all_data_frame_from_list(.data))
       stop("You can only pass data frames to the function.", call. = FALSE)
   } else {
@@ -79,7 +79,7 @@ download_this <- function(
   button_type <- match.arg(button_type)
 
   ## if list is passed to the function, only .xlsx will be used
-  if(class(.data) == "list")
+  if("list" %in% class(.data))
     output_extension <- ".xlsx"
 
   ## name of the final output file
@@ -89,7 +89,7 @@ download_this <- function(
   tmp_file <- fs::file_temp(ext = output_extension, tmp_dir = tempdir())
 
   if(output_extension == ".csv") {
-    readr::write_csv(x = .data, path = tmp_file)
+    readr::write_csv2(x = .data, path = tmp_file)
   } else {
     writexl::write_xlsx(x = .data, path = tmp_file)
   }
